Index: doc/man1/roarbaseclients.1
===================================================================
--- doc/man1/roarbaseclients.1	(revision 1624)
+++ doc/man1/roarbaseclients.1	(revision 4012)
@@ -24,5 +24,5 @@
 .TP
 \fBroarmon\fR
-Gets a copy of the audio data the server sends to the soundcard. This is usefull for streaming
+Gets a copy of the audio data the server sends to the soundcard. This is useful for streaming
 to a server like \fBicecast2\fR(1).
 
Index: doc/man1/roarctl.1
===================================================================
--- doc/man1/roarctl.1	(revision 1204)
+++ doc/man1/roarctl.1	(revision 4012)
@@ -86,5 +86,5 @@
 \fBflag ID FLAGS\fR, \fBunflag ID FLAGS\fR
 Sets or removes flags from a stream. ID is the stream id.
-FLAGS is a comma seperated list of flags.
+FLAGS is a comma separated list of flags.
 
 It is not possible to set all kinds of flags at runtime.
@@ -105,13 +105,13 @@
 .TP
 \fBserveroinfo\fR
-Gets Informations about server output.
+Gets Information about server output.
 
 .TP
 \fBlistclients\fR
-Gets Informations about clients.
+Gets Information about clients.
 
 .TP
 \fBliststreams\fR
-Gets Informations about streams.
+Gets Information about streams.
 
 .TP
Index: doc/man1/roard.1
===================================================================
--- doc/man1/roard.1	(revision 1525)
+++ doc/man1/roard.1	(revision 4012)
@@ -155,5 +155,5 @@
 .TP
 \fB--no-listen\fR
-Do not listen for new clients (only usefull for relaing, impleys --terminate).
+Do not listen for new clients (only useful for relaing, impleys --terminate).
 
 .TP
Index: doc/man1/roarify.1
===================================================================
--- doc/man1/roarify.1	(revision 3084)
+++ doc/man1/roarify.1	(revision 4012)
@@ -12,6 +12,6 @@
 
 .SH "DESCRIPTION"
-This command sets up a enviroment that enables all RoarAudio compatibility librarys.
-Audio data from applications should automaticly be redirected to roard. 
+This command sets up a environment that enables all RoarAudio compatibility librarys.
+Audio data from applications should automatically be redirected to roard. 
 
 .SH "SEE ALSO"
Index: doc/man1/roartestclients.1
===================================================================
--- doc/man1/roartestclients.1	(revision 732)
+++ doc/man1/roartestclients.1	(revision 4012)
@@ -18,5 +18,5 @@
 
 .SH "DESCRIPTION"
-This clients are primary for test perpose but may be usefull for someone
+This clients are primary for test perpose but may be useful for someone
 or can be used as examples.
 
@@ -34,5 +34,5 @@
 \fBroarsin\fR
 This is the complete version of the sinus generator from \fBroartut\fR(7).
-It plays a 5 secund middle C (523.2Hz) sine.
+It plays a 5 second middle C (523.2Hz) sine.
 
 .TP
Index: doc/man3/roar_simple_connect.3
===================================================================
--- doc/man3/roar_simple_connect.3	(revision 159)
+++ doc/man3/roar_simple_connect.3	(revision 4012)
@@ -13,5 +13,5 @@
 
 .SH "DESCRIPTION"
-This call opens a connection to the RoarAudio's sound server. This is usefull for controlling the server or
+This call opens a connection to the RoarAudio's sound server. This is useful for controlling the server or
 update meta data of any kind. For simple playback see \fBroar_simple_play\fR(3).
 To disconnect use \fBroar_disconnect\fR(3).
Index: doc/man3/roar_simple_new_stream.3
===================================================================
--- doc/man3/roar_simple_new_stream.3	(revision 159)
+++ doc/man3/roar_simple_new_stream.3	(revision 4012)
@@ -16,5 +16,5 @@
 
 .SH "DESCRIPTION"
-Opens a new stream to the sound server as a independet file handle (not an execed one). This is usefull if you still want
+Opens a new stream to the sound server as a independet file handle (not an execed one). This is useful if you still want
 some meta data or the volume to be updated after the stream is open.
 
@@ -27,5 +27,5 @@
 .TP
 \fBs\fR
-The stream object to be updated to corresponde to the new stream. This is usefull if use want to update some meta data
+The stream object to be updated to corresponde to the new stream. This is useful if use want to update some meta data
 after the stream has be opened as you can use all controll commands on this object.
 
Index: doc/man7/libroar.7
===================================================================
--- doc/man7/libroar.7	(revision 842)
+++ doc/man7/libroar.7	(revision 4012)
@@ -61,5 +61,5 @@
 The default port is 22.
 Note that you may need to use publickey based auth or ssh-agent because the application
-may start SSH in a non interactive enviroment and SSH can not ask you for a password.
+may start SSH in a non interactive environment and SSH can not ask you for a password.
 
 
Index: doc/man7/roartips.7
===================================================================
--- doc/man7/roartips.7	(revision 546)
+++ doc/man7/roartips.7	(revision 4012)
@@ -25,8 +25,8 @@
 
 The later one will show you all information current available of the server it self,
-the clients and the streams. This may include a lot of informations.
+the clients and the streams. This may include a lot of information.
 
 .SH "SERVER ADDRESS"
-There a serverel types of server addresses based on the protocoll used to communicate.
+There a serverel types of server addresses based on the protocol used to communicate.
 This lists the corrently implemented types in order of importance:
 
Index: doc/man7/roartut.7
===================================================================
--- doc/man7/roartut.7	(revision 417)
+++ doc/man7/roartut.7	(revision 4012)
@@ -49,5 +49,5 @@
  }
 
-Now we want to loop for \fBlength\fR secunds:
+Now we want to loop for \fBlength\fR seconds:
  while (t < 2*M_PI*freq*length) {
  }
Index: roarclients/roarctl.c
===================================================================
--- roarclients/roarctl.c	(revision 3961)
+++ roarclients/roarctl.c	(revision 4012)
@@ -94,5 +94,5 @@
         "\n"
         "  flag   ID FLAGS         - Sets flags FLAGS on stream ID. FLAGS may be a comma\n"
-        "                            seperated list of flags.\n"
+        "                            separated list of flags.\n"
         "  unflag ID FLAGS         - Unsets flags on a stream. See flag.\n"
         "\n"
@@ -110,7 +110,7 @@
         "  metaload ID FILE        - Loads meta data from file FILE and set it on stream ID\n"
         "\n"
-        "  serveroinfo             - Gets Informations about server output\n"
-        "  listclients             - Gets Informations about clients\n"
-        "  liststreams             - Gets Informations about streams\n"
+        "  serveroinfo             - Gets Information about server output\n"
+        "  listclients             - Gets Information about clients\n"
+        "  liststreams             - Gets Information about streams\n"
         "  allinfo                 - Get all infos\n"
        );
Index: roarclients/roarradio.c
===================================================================
--- roarclients/roarradio.c	(revision 3811)
+++ roarclients/roarradio.c	(revision 4012)
@@ -149,5 +149,5 @@
 
       if ( fscanf(http, "%79s %i %79s\n", buf0, &port, buf1) != 3 ) {
-       ROAR_ERR("HTTP protocoll error!, no initial HTTP/1.x-line!");
+       ROAR_ERR("HTTP protocol error!, no initial HTTP/1.x-line!");
        return 1;
       }
Index: roard/roard.c
===================================================================
--- roard/roard.c	(revision 3992)
+++ roard/roard.c	(revision 4012)
@@ -87,5 +87,5 @@
  printf(
         " --stream-flags D=F    - Set default flags for stream directions\n"
-        "                         D is the stream direction and F is a comma seperated\n"
+        "                         D is the stream direction and F is a comma separated\n"
         "                         list of flags in form +flag or -flag to set or unset\n"
         "                         a flag as default or remove it from the default\n"
@@ -171,5 +171,5 @@
 #ifdef IPV6_ADDRFORM
         " -64                   - Try to downgrade sockets from IPv6 into IPv4,\n"
-        "                         this is normaly not usefull.\n"
+        "                         this is normaly not useful.\n"
 #endif
         " -p  --port            - TCP Port to bind to\n"
@@ -181,5 +181,5 @@
         "     --proto-bits BITS - Set bits per sample parameter for protocol\n"
         "     --proto-codec E   - Set codec parameter for protocol\n"
-        "     --proto-chans C   - Set number of channels paramter for protocol\n"
+        "     --proto-chans C   - Set number of channels parameter for protocol\n"
         "     --proto-aiprofile PROFILE\n"
         "                       - Sets the audio profile for socket\n" 
@@ -200,7 +200,7 @@
         "                         You need the permissions to change the UID (normaly only root has)\n"
         " --no-listen           - Do not listen for new clients\n"
-        "                         (only usefull for relaing, impleys --terminate)\n"
+        "                         (only useful for relaing, impleys --terminate)\n"
         " --client-fh           - Comunicate with a client over this handle\n"
-        "                         (only usefull for relaing)\n"
+        "                         (only useful for relaing)\n"
         " --close-fh            - Closes the given fh\n"
         " --standby             - Start in standby state\n"
@@ -1586,5 +1586,5 @@
 
   } else if ( strcmp(k, "-p") == 0 || strcmp(k, "--port") == 0 ) {
    // This is only usefull in INET not UNIX mode.
 #ifdef ROAR_SUPPORT_LISTEN
    if ( *sock_addr == '/' )
@@ -1586,5 +1586,5 @@
 
   } else if ( strcmp(k, "-p") == 0 || strcmp(k, "--port") == 0 ) {
-   // This is only usefull in INET not UNIX mode.
+   // This is only useful in INET not UNIX mode.
 #ifdef ROAR_SUPPORT_LISTEN
    if ( *sock_addr == '/' )
